@@ -12,7 +12,7 @@ from .log_util import LogUtil
 
 class AppConfigUtil(object):
     def __init__(self, app_id: int):
-        self._cad_client = CadUtil()
+        self._cad_client = CadUtil(is_log=False)
         self._app_id = app_id
 
     @LogUtil()
